pub enum DenialReason {
OfferingNotSellable,
InventoryUnavailable,
SourceNotAllowed,
}Expand description
Reason a retail sale is denied before reaching checkout.
Variants
OfferingNotSellable
Offering not sellable retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Inventory unavailable retail operational signal for inventory, POS, reorder, recommendation, or review handling.
SourceNotAllowed
Source not allowed retail operational signal for inventory, POS, reorder, recommendation, or review handling.