pub enum Policy {
StandaloneSale,
IntegratedWithReservationCheckout,
ManagerOnlyComp,
}Expand description
POS policy deciding which retail sources are allowed and which price actions need manager review.
Variants
StandaloneSale
Standalone sale retail operational signal for inventory, POS, reorder, recommendation, or review handling.
IntegratedWithReservationCheckout
Integrated with reservation checkout retail operational signal for inventory, POS, reorder, recommendation, or review handling.
ManagerOnlyComp
Manager only comp retail operational signal for inventory, POS, reorder, recommendation, or review handling.
Implementations