pub enum Source {
StandaloneStaffSale {
staff_id: StaffId,
},
ReservationCheckout {
reservation_id: Id,
},
ExternalPosReconciliation,
}Expand description
Source of the retail sale attempt, used to prevent unsupported POS or reservation mutations.
Variants
StandaloneStaffSale
Standalone staff sale retail operational signal for inventory, POS, reorder, recommendation, or review handling.
ReservationCheckout
Reservation checkout retail operational signal for inventory, POS, reorder, recommendation, or review handling.
ExternalPosReconciliation
External pos reconciliation retail operational signal for inventory, POS, reorder, recommendation, or review handling.